langchain_firebase library

LangChain.dart integration module for Firebase (Gemini, VertexAI for Firebase, Firestore, etc.).

Classes

ChatFirebaseVertexAI
Wrapper around Firebase AI Logic (Gemini API via Firebase).
ChatFirebaseVertexAIOptions
Options to pass into the Vertex AI for Firebase model.
ChatFirebaseVertexAISafetySetting
Safety setting, affecting the safety-blocking behavior. Passing a safety setting for a category changes the allowed probability that content is blocked.

Enums

ChatFirebaseVertexAISafetySettingCategory
Safety settings categorizes.
ChatFirebaseVertexAISafetySettingThreshold
Controls the probability threshold at which harm is blocked.
FirebaseAIBackend
The Firebase AI backend to use.