safetySettings property

List<ChatFirebaseVertexAISafetySetting>? safetySettings
final

A list of unique ChatFirebaseVertexAISafetySetting instances for blocking unsafe content.

This will be enforced on the generated output. There should not be more than one setting for each type. The API will block any contents and responses that fail to meet the thresholds set by these settings.

This list overrides the default settings for each category specified. If there is no safety setting for a given category provided in the list, the API will use the default safety setting for that category.

Implementation

final List<ChatFirebaseVertexAISafetySetting>? safetySettings;