temperature property
Controls the randomness of the output.
Note: The default value varies by model, see the Model.temperature
attribute of the Model returned the getModel function.
Values can range from 0.0,1.0, inclusive. A value closer to 1.0 will
produce responses that are more varied and creative, while a value
closer to 0.0 will typically result in more straightforward responses
from the model.
Implementation
final double? temperature;