ChatFirebaseVertexAISafetySetting class

Safety setting, affecting the safety-blocking behavior. Passing a safety setting for a category changes the allowed probability that content is blocked.

Annotations

Constructors

ChatFirebaseVertexAISafetySetting({required ChatFirebaseVertexAISafetySettingCategory category, required ChatFirebaseVertexAISafetySettingThreshold threshold})
Safety setting, affecting the safety-blocking behavior. Passing a safety setting for a category changes the allowed probability that content is blocked.
const

Properties

category ChatFirebaseVertexAISafetySettingCategory
The category for this setting.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold ChatFirebaseVertexAISafetySettingThreshold
Controls the probability threshold at which harm is blocked.
final

Methods

copyWith({ChatFirebaseVertexAISafetySettingCategory? category, ChatFirebaseVertexAISafetySettingThreshold? threshold}) ChatFirebaseVertexAISafetySetting
Creates a copy of this ChatFirebaseVertexAISafetySetting object with the given fields replaced with the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(covariant ChatFirebaseVertexAISafetySetting other) bool
The equality operator.
override