ChatFirebaseVertexAISafetySettingCategory enum

Safety settings categorizes.

Docs: https://ai.google.dev/docs/safety_setting_gemini

Inheritance
  • Object
  • Enum
  • ChatFirebaseVertexAISafetySettingCategory
Available extensions

Values

unspecified → const ChatFirebaseVertexAISafetySettingCategory

The harm category is unspecified.

harassment → const ChatFirebaseVertexAISafetySettingCategory

The harm category is harassment.

hateSpeech → const ChatFirebaseVertexAISafetySettingCategory

The harm category is hate speech.

sexuallyExplicit → const ChatFirebaseVertexAISafetySettingCategory

The harm category is sexually explicit content.

dangerousContent → const ChatFirebaseVertexAISafetySettingCategory

The harm category is dangerous content.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ChatFirebaseVertexAISafetySettingCategory>
A constant List of the values in this enum, in order of their declaration.