ChatFirebaseVertexAISafetySettingThreshold enum

Controls the probability threshold at which harm is blocked.

Docs: https://ai.google.dev/docs/safety_setting_gemini

Inheritance
  • Object
  • Enum
  • ChatFirebaseVertexAISafetySettingThreshold
Available extensions

Values

unspecified → const ChatFirebaseVertexAISafetySettingThreshold

Threshold is unspecified, block using default threshold.

blockLowAndAbove → const ChatFirebaseVertexAISafetySettingThreshold

Block when low, medium or high probability of unsafe content.

blockMediumAndAbove → const ChatFirebaseVertexAISafetySettingThreshold

Block when medium or high probability of unsafe content.

blockOnlyHigh → const ChatFirebaseVertexAISafetySettingThreshold

Block when high probability of unsafe content.

blockNone → const ChatFirebaseVertexAISafetySettingThreshold

Always show regardless of probability of unsafe content.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ChatFirebaseVertexAISafetySettingThreshold>
A constant List of the values in this enum, in order of their declaration.