FirebaseAIBackend enum

The Firebase AI backend to use.

Inheritance
Available extensions

Values

vertexAI → const FirebaseAIBackend

Vertex AI Gemini API - requires Blaze plan (pay-as-you-go). Recommended for production use.

googleAI → const FirebaseAIBackend

Gemini Developer API - available on Spark plan (free tier). Has rate limits but no billing required.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FirebaseAIBackend>
A constant List of the values in this enum, in order of their declaration.